@@ -34,29 +34,28 @@
 #' @return Returns a distributed matrix.
 #' 
 #' @examples
-#' \dontrun{
-#' # Save code in a file "demo.r" and run with 2 processors by
-#' # > mpiexec -np 2 Rscript demo.r
+#' spmd.code = "
+#'   library(pbdDMAT, quiet = TRUE)
+#'   init.grid()
+#'   
+#'   if (comm.rank()==0){
+#'     x <- matrix(1:16, ncol=4)
+#'   } else {
+#'     x <- NULL
+#'   }
+#'   
+#'   dx <- as.ddmatrix(x, bldim=2)
+#'   dx
+#'   
+#'   ### Can also be common to all ranks
+#'   y <- matrix(1:25, 5, bldim=2)
+#'   dy <- as.ddmatrix(y)
+#'   dy
 #' 
-#' library(pbdDMAT, quiet = TRUE)
-#' init.grid()
+#'   finalize()
+#' "
 #' 
-#' if (comm.rank()==0){
-#'   x <- matrix(1:16, ncol=4)
-#' } else {
-#'   x <- NULL
-#' }
-#' 
-#' dx <- as.ddmatrix(x, bldim=2)
-#' dx
-#' 
-#' ### Can also be common to all ranks
-#' y <- matrix(1:25, 5, bldim=2)
-#' dy <- as.ddmatrix(y)
-#' dy
-#' 
-#' finalize()
-#' }
+#' pbdMPI::execmpi(spmd.code = spmd.code, nranks = 2L)
 #' 
 #' @keywords Distributing Data
 #' @name as.ddmatrix
@@ -76,17 +75,14 @@ base.mat.to.ddmat <- function(x, bldim=.pbd_env$BLDIM, ICTXT=.pbd_env$ICTXT)
   
   if (length(bldim) == 1) 
     bldim <- rep(bldim, 2) 
-  else if (diff(bldim) != 0)
-    comm.warning("Most ScaLAPACK routines do not allow for non-square blocking.  This is highly non-advised.")
+  ### NOTE non-square blocking checks deprecated in favor of checking explicitly
+  ### for the few affected routines.
   
   dim <- dim(x)
   ldim <- base.numroc(dim=dim, bldim=bldim, ICTXT=ICTXT, fixme=TRUE)
   descx <- base.descinit(dim=dim, bldim=bldim, ldim=ldim, ICTXT=ICTXT)
-  
   out <- base.mksubmat(x=x, descx=descx)
-  
   dx <- new("ddmatrix", Data=out, dim=dim, ldim=dim(out), bldim=bldim, ICTXT=ICTXT)
-  
   return(dx)
 }
 
@@ -148,27 +144,27 @@ distribute <- function(x, bldim=.pbd_env$BLDIM, xCTXT=0, ICTXT=.pbd_env$ICTXT)
 # Distribute dense, in-core matrices
 dmat.as.ddmatrix <- function(x, bldim=.pbd_env$BLDIM, ICTXT=.pbd_env$ICTXT)
 {
+  comm=get.comm.from.ICTXT(ICTXT)
   if (length(bldim)==1)
     bldim <- rep(bldim, 2L)
 
-  nprocs <- pbdMPI::comm.size()
-  owns <- pbdMPI::allreduce(as.integer(is.matrix(x)), op='sum')
-  
+  nprocs <- pbdMPI::comm.size(comm)
+  owns <- pbdMPI::allreduce(as.integer(is.matrix(x)), op='sum', comm=comm)
   # owned by one process 
   if (owns==1)
   { 
     iown <- is.matrix(x)
     if (iown)
-      iown <- pbdMPI::comm.rank()
+      iown <- pbdMPI::comm.rank(comm)
     else
       iown <- 0
-    iown <- pbdMPI::allreduce(iown, op='max')
+    iown <- pbdMPI::allreduce(iown, op='max', comm=comm)
     # return( distribute(x=x, bldim=bldim, xCTXT=0, ICTXT=ICTXT) )
     
     if (iown != 0)
       comm.stop("matrix must be on rank 0")
     
-    if (comm.rank() == 0)
+    if (comm.rank(comm) == 0)
     {
       dim <- dim(x)
       ldim <- base.numroc(dim=dim, bldim=bldim, ICTXT=ICTXT)
@@ -180,7 +176,7 @@ dmat.as.ddmatrix <- function(x, bldim=.pbd_env$BLDIM, ICTXT=.pbd_env$ICTXT)
       desc <- integer(9)
     }
     
-    desc <- allreduce(desc)
+    desc <- allreduce(desc, comm=comm)
     ## FIXME remove after pbdMPI fix
     desc <- as.integer(desc)
     
@@ -190,7 +186,9 @@ dmat.as.ddmatrix <- function(x, bldim=.pbd_env$BLDIM, ICTXT=.pbd_env$ICTXT)
   } 
   # global ownership is assumed --- this should only ever really happen in testing
   else if (owns==nprocs)
+  {
     return( base.mat.to.ddmat(x, bldim=bldim, ICTXT=ICTXT) )
+  }
   # neither of these two cases
   else 
     comm.stop("Matrix 'x' is defined on some, but not all processes. Consider using the redistribute() function.")
