@@ -11,24 +11,6 @@
 #' @return 
 #' \code{lu()} performs LU factorization.
 #' 
-#' @examples
-#' \dontrun{
-#' # Save code in a file "demo.r" and run with 2 processors by
-#' # > mpiexec -np 2 Rscript demo.r
-#' 
-#' library(pbdDMAT, quiet = TRUE)
-#' init.grid()
-#' 
-#' # don't do this in production code
-#' x <- matrix(1:9, 3)
-#' x <- as.ddmatrix(x)
-#' 
-#' y <- solve(t(A) %*% A)
-#' print(y)
-#' 
-#' finalize()
-#' }
-#' 
 #' @keywords Methods Linear Algebra
 #' @aliases lu
 #' @name ddmatrix-lu
@@ -42,6 +24,9 @@ setGeneric(name="lu", function(x) standardGeneric("lu"), package="pbdDMAT")
 setMethod("lu", signature(x="ddmatrix"), 
   function(x)
   {
+    if (x@bldim[1L] != x@bldim[2L])
+      comm.stop(paste0("lu() requires a square blocking factor; have ", x@bldim[1L], "x", x@bldim[2L]))
+    
     desca <- base.descinit(dim=x@dim, bldim=x@bldim, ldim=x@ldim, ICTXT=x@ICTXT)
     
     out <- base.rpdgetrf(a=x@Data, desca=desca)
@@ -51,6 +36,3 @@ setMethod("lu", signature(x="ddmatrix"),
     return( x )
   }
 )
-
-
-
